DSTokenManager class

Manages fingerprint authentication payloads (opaque tokens)

Constructors

DSTokenManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTokens() Future<void>
getToken(String userId) Future<String?>
isTokenValid(String token) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeToken(String userId) Future<void>
storeToken(String userId, String token) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited