createAccount method
Creates a new user account with the given credentials
Implementation
@override
Future<void> createAccount(
String email,
String password, {
String? displayName,
}) async {
_ensureInitialized();
}
Creates a new user account with the given credentials
@override
Future<void> createAccount(
String email,
String password, {
String? displayName,
}) async {
_ensureInitialized();
}